@@ -790,7 +790,7 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 	while(new_button.image){
 		ClutterActor* sample_button;
 		int loop_id = counter+loop_type;
-		gchar* full_image = tangle_lookup_filename(new_button.image);
+		gchar* full_image = g_strdup(new_button.image);
 		gchar* full_sound = g_strdup_printf("%s", new_button.sound);
 		//printf("new_sample: '%s', '%s'\n",full_image,full_sound);
 		sample_button = jammo_sample_button_new_with_type(type_by_id(loop_id));
