@@ -27,6 +27,7 @@ enum {
 	PROP_DISABLED_SLOTS_END,
 	PROP_PEN_MODE,      //clicking to track will make new notes
 	PROP_ERASER_MODE,      //clicking to note on track will remove note
+	PROP_GRID,             //Is grid visible or hidden
 	PROP_EDITING_ENABLED
 };
 
@@ -588,6 +589,9 @@ static void jammo_miditrack_view_set_property(GObject* object, guint prop_id, co
 		case PROP_ERASER_MODE:
 			jammo_miditrack_view_set_eraser_mode(miditrack_view, g_value_get_boolean(value));
 			break;
+		case PROP_GRID:
+			jammo_miditrack_view_set_show_grid(miditrack_view, g_value_get_boolean(value));
+			break;
 		case PROP_EDITING_ENABLED:
 			jammo_miditrack_view_set_editing_enabled(miditrack_view, g_value_get_boolean(value));
 			break;
@@ -636,6 +640,9 @@ static void jammo_miditrack_view_get_property(GObject* object, guint prop_id, GV
 		case PROP_ERASER_MODE:
 			g_value_set_boolean(value, miditrack_view->priv->eraser_mode);
 			break;
+		case PROP_GRID:
+			g_value_set_boolean(value, miditrack_view->priv->show_grid);
+			break;
 		case PROP_EDITING_ENABLED:
 			g_value_set_boolean(value, miditrack_view->priv->editing_enabled);
 			break;
@@ -809,6 +816,17 @@ static void jammo_miditrack_view_class_init(JammoMiditrackViewClass* miditrack_v
 	                                "Clicking will delete note",
 	                                FALSE,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+/**
+	 * JammoMiditrackView:grid:
+	 *
+	 * Is grid visible or hidden.
+	 */
+	g_object_class_install_property(gobject_class, PROP_GRID,
+	                                g_param_spec_boolean("grid",
+	                                "Visible grid",
+	                                "Whether grid is visible or hidden",
+	                                FALSE,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (gobject_class, sizeof (JammoMiditrackViewPrivate));
 }
@@ -818,7 +836,6 @@ static void jammo_miditrack_view_init(JammoMiditrackView* miditrack_view) {
 	miditrack_view->priv = G_TYPE_INSTANCE_GET_PRIVATE(miditrack_view, JAMMO_TYPE_MIDITRACK_VIEW, JammoMiditrackViewPrivate);
 
 	miditrack_view->priv->editing_enabled = TRUE;
-	miditrack_view->priv->show_grid = TRUE;
 
 	miditrack_view->priv->hilight_color.red = 0;
 	miditrack_view->priv->hilight_color.green = 255;
