@@ -256,7 +256,7 @@ gboolean gems_profile_manager_create_default_user_profile(gchar* passworddata, g
 	GRand* grand = g_rand_new_with_seed(time(NULL));
 	
 	// Create profile with default informationm, except id (random), password (given) and age (given)
-	jammo_profile_container* profile = gems_teacher_server_create_profile(g_rand_int(grand),"defaultuser",passworddata,"none","FirstName","LastName",age);
+	jammo_profile_container* profile = gems_teacher_server_create_profile(g_rand_int(grand),"defaultuser",passworddata,"none","FirstName","LastName",age,0);
 
 	if(profile)
 	{
@@ -280,10 +280,7 @@ gboolean gems_profile_manager_logout()
 	ProfileManager* pm = gems_get_data()->pm;
 	if(pm == NULL) return FALSE;
 	
-	/* TODO enable this when all other encrypted profile related are done
-	 * TODO add checks for each call (for NULL's)
-	 * TODO add more logging
-	 */
+	/* TODO add checks for each call (for NULL's) */
 	 
 	// Is it necessary to save profile
 	if(profilemanager_is_authenticated(pm))
@@ -292,7 +289,6 @@ gboolean gems_profile_manager_logout()
 		{
 			// Get all profile information to one line
 			guchar* profile = (guchar*)profilemanager_storage_serialize_profile(pm);
-			printf("%s\n",profilemanager_storage_serialize_profile(pm));
 			guint profilelength = strlen((gchar*)profile)+1;
 			guint hashlength = profilelength;
 		
@@ -398,12 +394,24 @@ guint16 gems_profile_manager_get_age(gems_peer_profile* profile)
 	else return profile->age;
 }
 
-guint16 gems_profile_manager_get_avatar_id(gems_peer_profile* profile)
+guint32 gems_profile_manager_get_avatar_id(gems_peer_profile* profile)
 {
-	if(profile == NULL) return 0; // TODO implement avatars ?
+	if(profile == NULL)
+	{
+		ProfileManager* pm = gems_get_data()->pm;
+		if(pm == NULL) return 0;
+		return profilemanager_get_avatarid(pm);
+	}
 	else return profile->avatarid;
 }
 
+gboolean gems_profile_manager_set_avatar_id(guint32 avatarid)
+{
+	ProfileManager* pm = gems_get_data()->pm;
+	if(pm == NULL) return FALSE;
+	return profilemanager_set_avatarid(pm,avatarid);
+}
+
 /* Get points */
 guint32 gems_profile_manager_get_points()
 {
